@@ -70,7 +70,6 @@ U61_AloneMenu::U61_AloneMenu(U61_Menu *parent)
   add_item(new U61_Button("Options"));
   add_item(new U61_Button("Sound"));
   select(0);
-  shade();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -87,6 +86,7 @@ U61_Menu *U61_AloneMenu::validate()
     case 0:
       next_menu=parent_menu;
       U61_Global::game.stop();
+      unshade();
       break;
     case 1:
       next_menu=back();
@@ -115,6 +115,7 @@ U61_Menu *U61_AloneMenu::back()
   next_menu=new U61_PausingMenu(this);
   U61_Time::resume();
   U61_Global::game.configure_hot();
+  unshade();
 
   return next_menu;
 }
