@@ -72,14 +72,14 @@ char *U61_Application::get_title()
 /*
  * main function of the application
  */
-int U61_Application::main(int /*argc*/, char** /*argv*/)
+int U61_Application::main(int argc, char **argv)
 {
-  //CL_SetupCore::init();
-  //CL_SetupCore::init_display();
-  //CL_SetupCore::init_sound();
-  //CL_SetupCore::init_network();
+  CL_SetupCore::init();
+  CL_SetupCore::init_display();
+  CL_SetupCore::init_sound();
+  CL_SetupCore::init_network();
 
-  if (U61_Global::game.init())
+  if (U61_Global::game.init(argv[0]))
     {
       U61_Global::game.run();
     }
@@ -87,32 +87,9 @@ int U61_Application::main(int /*argc*/, char** /*argv*/)
 
   return 0;
 
-  //CL_SetupCore::deinit_network();    
-  //CL_SetupCore::deinit_sound();
-  //CL_SetupCore::deinit_display();
-  //CL_SetupCore::deinit();
-}
-
-/*--------------------------------------------------------------------------*/
-/*
- * initialization of ClanLib modules
- */
-void U61_Application::init_modules()
-{
-  CL_SetupCore::init();
-  CL_SetupCore::init_display();
-  CL_SetupCore::init_sound();
-  CL_SetupCore::init_network();
-}
-
-/*--------------------------------------------------------------------------*/
-/*
- * de-initialization of ClanLib modules
- */
-void U61_Application::deinit_modules()
-{
   CL_SetupCore::deinit_network();    
   CL_SetupCore::deinit_sound();
   CL_SetupCore::deinit_display();
   CL_SetupCore::deinit();
 }
+
