@@ -247,6 +247,13 @@ int U61_ClientProtocol::recv_next_packet()
 	}
       break;
     case ACCELERATION_RECEIVED:
+      if ((result=recv_curse_delay())==DONE)
+	{
+	  stage=CURSE_DELAY_RECEIVED;
+	  //cout<<"stage=CURSE_DELAY_RECEIVED\n";
+	}
+      break;
+    case CURSE_DELAY_RECEIVED:
       if ((result=recv_time())==DONE)
 	{
 	  stage=TIME_RECEIVED;
@@ -491,6 +498,26 @@ int U61_ClientProtocol::recv_acceleration()
   return result;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Receives the curse delay that will be used to initialize the local maps
+ */
+int U61_ClientProtocol::recv_curse_delay()
+{
+  int result=LATER;
+
+  if (connection->peek())
+    {
+      if (connection->recv(&curse_delay))
+	{
+	  result=DONE;
+	  //cout<<"curse_delay="<<curse_delay<<"\n";
+	}
+    }
+
+  return result;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * Receives the time that will be used to initialize the local maps
@@ -519,7 +546,7 @@ void U61_ClientProtocol::start_game()
 {
   U61_Global::game.do_network_join(script,
 				   id0,id1,
-				   initial_speed,acceleration,
+				   initial_speed,acceleration,curse_delay,
 				   time);
 }
 
