@@ -74,6 +74,8 @@ class U61_Config
   char data_file[U61_STRING_SIZE];
   char script_file[U61_STRING_SIZE];
 
+  bool fullscreen;
+
   char server_id[U61_STRING_SIZE];
   int network_port;
   int network_channel;
@@ -109,6 +111,8 @@ class U61_Config
   static char *const ID_DATA_FILE="cfg_data_file";
   static char *const ID_SCRIPT_FILE="cfg_script_file";
 
+  static char *const ID_FULLSCREEN="cfg_fullscreen";
+
   static char *const ID_SERVER_ID="cfg_server_id";
   static char *const ID_NETWORK_PORT="cfg_network_port";
   static char *const ID_NETWORK_CHANNEL="cfg_network_channel";
