@@ -85,13 +85,18 @@ public:
     int offset_target_y[NB_SIZE];
     int offset_preview_x[NB_SIZE];
     int offset_preview_y[NB_SIZE];
-    int offset_misc_x[NB_SIZE];
-    int offset_misc_y[NB_SIZE];
+    int offset_curses_x[NB_SIZE];
+    int offset_curses_y[NB_SIZE];
+    int offset_antedotes_x[NB_SIZE];
+    int offset_antedotes_y[NB_SIZE];
+    int offset_next_curse_x[NB_SIZE];
+    int offset_next_curse_y[NB_SIZE];
    
     int nb_map;
 
     CL_Font *font_menu;
     CL_Font *font_info[NB_SIZE];
+    CL_Font *font_symbol[NB_SIZE];
  
     CL_SoundBuffer *sound_game_start;
     CL_SoundBuffer *sound_menu_move;
@@ -104,8 +109,7 @@ public:
     CL_SoundBuffer *mikmod_test;
  
     CL_Surface *square[NB_SQUARE_TYPE][NB_SIZE];
-    CL_Surface *curse_bg[NB_SIZE];
-    CL_Surface *curse_fg[NB_SIZE];
+    CL_Surface *curse[NB_SIZE];
     CL_Surface *prevision[NB_SIZE];
     CL_Surface *explosion[NB_SIZE];
 
@@ -116,6 +120,8 @@ public:
 
     CL_Surface *info[NB_SIZE];
 
+    static char *const SYMBOL_CURSE="-";
+    static char *const SYMBOL_ANTEDOTE="+";
 
 protected:
     CL_ResourceManager *manager;
@@ -143,10 +149,18 @@ protected:
                          "property/offset_preview_x_big";
     static char *const ID_PROPERTY_OFFSET_PREVIEW_Y_BIG=
                          "property/offset_preview_y_big";
-    static char *const ID_PROPERTY_OFFSET_MISC_X_BIG=
-                         "property/offset_misc_x_big";
-    static char *const ID_PROPERTY_OFFSET_MISC_Y_BIG=
-                         "property/offset_misc_y_big";
+    static char *const ID_PROPERTY_OFFSET_CURSES_X_BIG=
+                         "property/offset_curses_x_big";
+    static char *const ID_PROPERTY_OFFSET_CURSES_Y_BIG=
+                         "property/offset_curses_y_big";
+    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_X_BIG=
+                         "property/offset_antedotes_x_big";
+    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_Y_BIG=
+                         "property/offset_antedotes_y_big";
+    static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_X_BIG=
+                         "property/offset_next_curse_x_big";
+    static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_Y_BIG=
+                         "property/offset_next_curse_y_big";
 
     static char *const ID_PROPERTY_OFFSET_MAP_X_SMALL=
                          "property/offset_map_x_small";
@@ -168,14 +182,24 @@ protected:
                          "property/offset_preview_x_small";
     static char *const ID_PROPERTY_OFFSET_PREVIEW_Y_SMALL=
                          "property/offset_preview_y_small";
-    static char *const ID_PROPERTY_OFFSET_MISC_X_SMALL=
-                         "property/offset_misc_x_small";
-    static char *const ID_PROPERTY_OFFSET_MISC_Y_SMALL=
-                         "property/offset_misc_y_small";
+    static char *const ID_PROPERTY_OFFSET_CURSES_X_SMALL=
+                         "property/offset_curses_x_small";
+    static char *const ID_PROPERTY_OFFSET_CURSES_Y_SMALL=
+                         "property/offset_curses_y_small";
+    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_X_SMALL=
+                         "property/offset_antedotes_x_small";
+    static char *const ID_PROPERTY_OFFSET_ANTEDOTES_Y_SMALL=
+                         "property/offset_antedotes_y_small";
+    static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_X_SMALL=
+                         "property/offset_next_curse_x_small";
+    static char *const ID_PROPERTY_OFFSET_NEXT_CURSE_Y_SMALL=
+                         "property/offset_next_curse_y_small";
 
     static char *const ID_FONT_MENU="font/menu";
     static char *const ID_FONT_INFO_BIG="font/info_big";
     static char *const ID_FONT_INFO_SMALL="font/info_small";
+    static char *const ID_FONT_SYMBOL_BIG="font/symbol_big";
+    static char *const ID_FONT_SYMBOL_SMALL="font/symbol_small";
 
     static char *const ID_SOUND_GAME_START="sound/game_start";
     static char *const ID_SOUND_MENU_MOVE="sound/menu_move";
@@ -187,13 +211,12 @@ protected:
  
     static char *const ID_SQUARE_BIG="square/big_n";
     static char *const ID_SQUARE_SMALL="square/small_n";
-    static char *const ID_SQUARE_CURSE_FG="curse_fg";
-    static char *const ID_SQUARE_CURSE_BG="curse_bg";
+    static char *const ID_SQUARE_CURSE="curse";
     static char *const ID_SQUARE_PREVISION="prevision";
     static char *const ID_SQUARE_EXPLOSION="explosion";
 
-    static char *const ID_MAP_BIG="map/big_n";
-    static char *const ID_MAP_SMALL="map/small_n";
+    static char *const ID_MAP_BIG="map/big_";
+    static char *const ID_MAP_SMALL="map/small_";
     static char *const ID_MAP_NUMBER="map/number";
 
     static char *const ID_BACK_MAIN="back/main";
