@@ -184,7 +184,7 @@ bool U61_Dispatcher::process()
       else
 	{
           //cout<<"Dispatcher receiving event "<<event<<"\n";
-          if (event.code!=U61_Event::KILL)
+          if (event.code==U61_Event::START_STOP)
 	    {
                busy_flag[event.target]=true;
 	    }
@@ -201,6 +201,17 @@ bool U61_Dispatcher::process()
   while (!empty_out())
     {
       event=get_out();
+
+      /*
+       * REQUEST_CURSE events are copied into the local queue
+       * since the target can be on a the same machine
+       * than the sender
+       */
+      if (event.code==U61_Event::REQUEST_CURSE)
+      {
+        put_in(event,event.target);
+      }
+
       //cout<<"Dispatcher sending event "<<event<<"\n";
       if (!send(event))
 	{
