@@ -64,19 +64,21 @@ class U61_Event
 
     START_STOP,
     KILL,
+
     NAME_LETTER,
+    CHANGE_BACKGROUND,
 
     MOVE_LEFT, MOVE_RIGHT,
     ROTATE_LEFT, ROTATE_RIGHT,
     MOVE_DOWN, DROP,
-    NEXT_VICTIM, PREV_VICTIM,
+    SET_VICTIM,NEXT_VICTIM,PREV_VICTIM,
     USE_ANTEDOTE,
  
     NEW_BLOCK,
     LOOSE,
     NEW_CURSE,
     REQUEST_CURSE,
-    CURSE
+    DO_CURSE
   };  
 
   unsigned int code : 8;
