@@ -59,6 +59,7 @@
 #include "clientdispatcher.h"
 #include "serverdispatcher.h"
 #include "localdispatcher.h"
+#include "utils.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -94,7 +95,7 @@ U61_Game::~U61_Game()
  * are likely to fail is the game is not correctly installed or
  * parametered
  */
-bool U61_Game::init()
+bool U61_Game::init(char *filename)
 {
   bool success=true;
     
@@ -109,6 +110,8 @@ bool U61_Game::init()
   protocol=NULL;
   dispatcher=NULL;
 
+  strcpy(exe_name,filename);
+
   U61_Global::config.read();
     
   U61_Script::init();
@@ -121,36 +124,15 @@ bool U61_Game::init()
 
   if (success)
     {
-      //cout<<"Trying video mode\n";
-      try
-	{
-	  CL_Display::set_videomode(U61_Global::data.screen_w,
-				    U61_Global::data.screen_h,16,false);
-	}
-      catch (CL_Error e)
-	{
-          cout<<"Error setting 16-bit video mode : "
-	      <<e.message
-	      <<" , trying 8-bit\n";
-
-	  try
-            {
-	      CL_Display::set_videomode(U61_Global::data.screen_w,
-					U61_Global::data.screen_h,8,false);
-	    }
-	  catch (CL_Error e)
-	    {
-	      cout<<"Error setting 8-bit video mode : "
-		  <<e.message
-		  <<" , giving up\n";
-	      success=false; 
-	    }
-	}
+      success=success && 
+	U61_Utils::set_videomode(U61_Global::data.screen_w,
+			 	 U61_Global::data.screen_h,
+				 U61_Global::config.fullscreen);
     }
 
   if (success)
     {
-        success=success && U61_Global::data.load2();
+      success=success && U61_Global::data.load2();
     }  
 
   //cout<<"Setting video mode\n";
@@ -161,11 +143,10 @@ bool U61_Game::init()
 
 /*--------------------------------------------------------------------------*/
 /*
- * closes the game sand exits "cleanly" ;)
+ * closes the game and exits "cleanly" ;)
  */
 void U61_Game::deinit()
 {
-
   U61_Global::config.write();
   U61_Global::data.unload();
 }
@@ -280,6 +261,16 @@ void U61_Game::quit()
   state=STATE_QUIT;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * quits the game and restart it (call to "exec") 
+ */
+void U61_Game::restart()
+{
+  deinit();
+  U61_Platform::exec(exe_name);
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * polls the keyboard, and calls any function that has to be call
