@@ -73,10 +73,11 @@ class U61_Game
 
   U61_Game();
   ~U61_Game();
-  bool init();
+  bool init(char *filename);
   void deinit();
   void run();
   void quit();
+  void restart();
 
   void configure_cold();
   void configure_hot();
@@ -103,6 +104,7 @@ class U61_Game
   int curse_delay;
 
  protected:
+  char exe_name[U61_STRING_SIZE];
   U61_MenuInput menu_input;
   U61_PlayerInput player_input[U61_Layout::NB_PLAYERS_LOCAL]; 
   U61_Player player[U61_Layout::NB_PLAYERS_TOTAL];
