@@ -39,7 +39,7 @@
 
 #include "joinmenu.h"
 #include "networkmenu.h"
-#include "emptymenu.h"
+#include "nonpausingmenu.h"
 #include "button.h"
 #include "edit.h"
 #include "global.h"
@@ -78,7 +78,7 @@ U61_Menu *U61_JoinMenu::validate()
     switch (selection)
     {
     case 0:
-        next_menu=new U61_EmptyMenu(new U61_NetworkMenu(this));
+        next_menu=new U61_NonPausingMenu(new U61_NetworkMenu(this));
         U61_Global::game.start_network_join();
         break;
     }
