@@ -59,11 +59,14 @@ public:
     
     void reset();
     void init(U61_Player *p,int x,int y,int s);
+    int get_player_id();
+    bool is_player_available();
 
     bool has_background_changed();
     void draw_background(CL_Canvas *target);
 
     void draw();
+
 protected:
     bool active;
     U61_Player *player;
