@@ -72,7 +72,6 @@ U61_MultiplayerMenu::U61_MultiplayerMenu(U61_Menu *parent)
   add_item(new U61_Button("Player 4 options"));
   add_item(new U61_Button("Sound"));
   select(0);
-  shade();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -89,6 +88,7 @@ U61_Menu *U61_MultiplayerMenu::validate()
     case 0:
       next_menu=parent_menu;
       U61_Global::game.stop();
+      unshade();
       break;
     case 1:
       next_menu=back();
@@ -124,6 +124,7 @@ U61_Menu *U61_MultiplayerMenu::back()
   next_menu=new U61_PausingMenu(this);
   U61_Time::resume();
   U61_Global::game.configure_hot();
+  unshade();
 
   return next_menu;
 }
