@@ -41,7 +41,9 @@
 #include <string.h>
 #include <stdio.h>
 
+#include "const.h"
 #include "number.h"
+#include "menuinput.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -73,8 +75,8 @@ U61_Number::U61_Number(char *label, int *val,
  */
 void U61_Number::update()
 {
-    char buffer1[1000];
-    char buffer2[1000];
+    char buffer1[U61_STRING_SIZE];
+    char buffer2[U61_STRING_SIZE];
 
     /*
      * puts the number into a string
@@ -85,7 +87,7 @@ void U61_Number::update()
      * we want the text in the item to look like "blablabla is on"
      */
     strcpy(buffer1,name);
-    strcat(buffer1," ");
+    strcat(buffer1,SEPARATOR);
     strcat(buffer1,buffer2);
 
     /*
@@ -140,11 +142,12 @@ bool U61_Number::action(int key)
 
     switch (key)
     {
-    case 9:
+    case U61_MenuInput::KEY_ENTER:
+    case U61_MenuInput::KEY_RIGHT:
         changed=true;
         inc();
         break;
-    case 8:
+    case U61_MenuInput::KEY_LEFT:
         changed=true;
         dec();
         break;
@@ -152,3 +155,16 @@ bool U61_Number::action(int key)
     
     return changed;
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * selection of the item (only selects the number value)
+ */
+void U61_Number::select()
+{
+    int start;
+
+    start=strlen(name);
+    
+    select_right(start); 
+}
