@@ -43,6 +43,7 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 #include "platform.h"
 #include "const.h"
@@ -125,6 +126,62 @@ char *U61_Platform::get_data_path()
   return buffer;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the path for builtin themes (/usr/local/share/u61/theme...)
+ */
+char *U61_Platform::get_builtin_theme_path()
+{
+  static char buffer[U61_STRING_SIZE];
+
+  strcpy(buffer,get_data_path());
+  strcat(buffer,"theme/");
+
+  return buffer;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the path for builtin scripts (/usr/local/share/u61/script...)
+ */
+char *U61_Platform::get_builtin_script_path()
+{
+  static char buffer[U61_STRING_SIZE];
+
+  strcpy(buffer,get_data_path());
+  strcat(buffer,"script/");
+
+  return buffer;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the path for user themes (/home/ufoot/.u61/theme...)
+ */
+char *U61_Platform::get_user_theme_path()
+{
+  static char buffer[U61_STRING_SIZE];
+
+  strcpy(buffer,get_user_path());
+  strcat(buffer,"theme/");
+
+  return buffer;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the path for user scripts (/home/ufoot/.u61/script...)
+ */
+char *U61_Platform::get_user_script_path()
+{
+  static char buffer[U61_STRING_SIZE];
+
+  strcpy(buffer,get_user_path());
+  strcat(buffer,"script/");
+
+  return buffer;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the name of the config file (/home/ufoot/.u61/config for instance)
@@ -228,7 +285,9 @@ bool U61_Platform::create_user_dir()
     }    
   else
     {
-      if (mkdir(get_user_path(),S_IRUSR|S_IWUSR|S_IXUSR)==0)
+      if ((mkdir(get_user_path(),S_IRUSR|S_IWUSR|S_IXUSR)==0)
+	  && (mkdir(get_user_theme_path(),S_IRUSR|S_IWUSR|S_IXUSR)==0)
+	  && (mkdir(get_user_script_path(),S_IRUSR|S_IWUSR|S_IXUSR)==0))
 	{
 	  ok=true;
 	}
@@ -236,3 +295,25 @@ bool U61_Platform::create_user_dir()
 
   return ok;
 }
+
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Quits U61 and launches "file"
+ * Used when the player changes the current theme
+ */
+void U61_Platform::exec(char *file)
+{
+  //cout<<"executing \""<<file<<"\"\n";
+
+  CL_SetupCore::deinit_network();    
+  CL_SetupCore::deinit_sound();
+  CL_SetupCore::deinit_display();
+  CL_SetupCore::deinit();
+
+  // This function should never return
+  execl(file,file,NULL);
+}
+
+
+
