@@ -131,13 +131,22 @@ int U61_Player::get_id()
   return id;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the id of the target of a player
+ */
+int U61_Player::get_target_id()
+{
+  return last.get_target_id();
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the name of a player
  */
 char *U61_Player::get_name()
 {
-  return sure.get_name();
+  return last.get_name();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -167,6 +176,33 @@ U61_Block U61_Player::get_next_block()
   return last.get_next_block();
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the number of persistent curses activated
+ */
+int U61_Player::get_nb_curse()
+{
+  return last.get_nb_curse();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the number of antedotes available
+ */
+int U61_Player::get_nb_antedote()
+{
+  return last.get_nb_antedote();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the name of the current curse
+ */
+char *U61_Player::get_curse_name()
+{
+  return last.get_curse_name();
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * sets the player as a local player
@@ -188,8 +224,10 @@ void U61_Player::init_local(U61_Input *input,
   local=true;
 
   set_id(id);
-  sure.reset(U61_Global::game.initial_speed,
-	     U61_Global::game.acceleration);
+  sure.init(id,
+	     U61_Global::game.initial_speed,
+	     U61_Global::game.acceleration,
+             U61_Global::game.curse_delay);
   copy_sure_to_last();
 
   prevision=&(conf->prevision);
@@ -223,8 +261,10 @@ void U61_Player::init_network(U61_Dispatcher *d,
   local=false;
 
   set_id(id);
-  sure.reset(U61_Global::game.initial_speed,
-	     U61_Global::game.acceleration);
+  sure.init(id,
+	     U61_Global::game.initial_speed,
+	     U61_Global::game.acceleration,
+             U61_Global::game.curse_delay);
   copy_sure_to_last();
 
   prevision=&(U61_Global::config.network_prevision);
@@ -249,6 +289,15 @@ bool U61_Player::is_available()
   return available;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns true if the player is active
+ */
+bool U61_Player::is_active()
+{
+  return last.is_active();;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns true if the player is a local player
@@ -278,7 +327,7 @@ void U61_Player::pump_events()
     {
       changed=true;
       evt=source->get();
-      U61_Player::handle_event(evt);
+      handle_event(&evt);
       copy->put(evt);
       if (evt.code==U61_Event::KILL)
 	{
@@ -286,6 +335,12 @@ void U61_Player::pump_events()
 	}
     }
 
+  while (sure.exists_request_event())
+    {
+      evt=sure.get_request_event();
+      copy->put(evt);
+    }
+
   if (changed)
     {
       copy_sure_to_last();
@@ -303,11 +358,11 @@ void U61_Player::pump_events()
 /*
  * pumps an event
  */
-void U61_Player::handle_event(U61_Event evt)
+void U61_Player::handle_event(U61_Event *evt)
 {
       if (sure.is_active())
 	{
-	  if (evt.code==U61_Event::START_STOP)
+	  if (evt->code==U61_Event::START_STOP)
 	    {
 	      stop();
 	    }
@@ -318,9 +373,9 @@ void U61_Player::handle_event(U61_Event evt)
 	}
       else
 	{
-	  if (evt.code==U61_Event::START_STOP)
+	  if (evt->code==U61_Event::START_STOP)
 	    {
-	      start(evt.time);
+	      start(evt->time);
 	    } 
     }
 }
