@@ -83,9 +83,13 @@ class U61_Player
   int get_id();
 
   char *get_name();
+  int get_target_id();
   int get_score();
   int get_best_score();
   U61_Block get_next_block();
+  int get_nb_curse();
+  int get_nb_antedote();
+  char *get_curse_name();
 
   void init_local(U61_Input *input,
                   U61_Dispatcher *d,
@@ -97,6 +101,7 @@ class U61_Player
 		    int id);
 
   bool is_available();
+  bool is_active();
   bool is_local();
 
   void pump_events();
@@ -118,7 +123,7 @@ class U61_Player
 
   bool *prevision;
 
-  void handle_event(U61_Event evt);
+  void handle_event(U61_Event *evt);
   void start(int time);
   void stop();
 
