@@ -221,6 +221,13 @@ int U61_ServerProtocol::send_next_packet()
 	}
       break;
     case ACCELERATION_SENT:
+      if ((result=send_curse_delay())==DONE)
+	{
+	  stage=CURSE_DELAY_SENT;
+	  //cout<<"stage=CURSE_DELAY_SENT\n";
+	}
+      break;
+    case CURSE_DELAY_SENT:
       if ((result=send_time())==DONE)
 	{
 	  stage=TIME_SENT;
@@ -512,6 +519,23 @@ int U61_ServerProtocol::send_acceleration()
   return result;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Sends the curse delay that will be usable by the client to initialize its
+ * player's maps
+ */
+int U61_ServerProtocol::send_curse_delay()
+{
+  int result=LATER;
+
+  if (connection[new_connection]->send(U61_Global::config.curse_delay))
+    {
+      result=DONE;
+    }
+ 
+  return result;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * Sends the time that will be usable by the client to initialize its
