@@ -103,7 +103,7 @@ int U61_Time::last_for_display;
  */
 void U61_Time::reset(int time)
 {
-    reset_offset=CL_System::get_time()+time*TIME_UNIT;
+    reset_offset=CL_System::get_time()-time*TIME_UNIT;
     alter_offset=0;
     pause_offset=0;
     paused=false;
@@ -184,7 +184,7 @@ int U61_Time::for_effect()
  */
 void U61_Time::alter(int delta)
 {
-    alter_offset+=delta*TIME_UNIT;
+    alter_offset-=delta*TIME_UNIT;
 }
 
 /*--------------------------------------------------------------------------*/
