@@ -57,7 +57,7 @@
  */
 static int dummy_random()
 {
-    return random();
+  return random();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -66,13 +66,65 @@ static int dummy_random()
  */
 int U61_Utils::random(int scale)
 {
-    int temp;
+  int temp;
 
-    temp=dummy_random();
-    if (temp<0)
+  temp=dummy_random();
+  if (temp<0)
     {
-        temp=-temp;
+      temp=-temp;
     }
 
-    return (temp%scale);
+  return (temp%scale);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Sets a videomode
+ * This function simply calls ClanLib's set_videomode function with several
+ * parameters, so that it only fails in critical cases
+ */
+bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
+{
+  bool ok=false;
+
+  if (!ok)
+    {
+      try 
+	{
+	  CL_Display::set_videomode(w,h,16,fullscreen);
+	  ok=true;
+	}
+      catch (CL_Error e)
+	{
+          try
+	    {
+	      CL_Display::set_videomode(w,h,16,!fullscreen);
+	      ok=true;
+	    }
+	  catch (CL_Error e)
+	    {
+	      try
+		{
+		  CL_Display::set_videomode(w,h,8,fullscreen);
+		  ok=true;
+		}
+	      catch (CL_Error e)
+		{
+		  try
+		    {
+		      CL_Display::set_videomode(w,h,8,!fullscreen);
+		      ok=true;
+		    }
+		  catch (CL_Error e)
+		    {
+		      cout<<"Invalid video mode: w="<<w
+			  <<" h="<<h
+			  <<" fullscreen="<<fullscreen<<"\n";
+		    }
+		}
+	    }
+	}
+    }
+
+  return ok;
 }
